"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientMethodHandler = void 0;
const bindings_1 = require("../bindings");
/** The MethodHandler which sends the commands to the Rust side. */
class ClientMethodHandler {
    constructor(options) {
        // The rust client object is not extensible
        if (Object.isExtensible(options)) {
            this.methodHandler = (0, bindings_1.createClient)(JSON.stringify(options));
        }
        else {
            this.methodHandler = options;
        }
    }
    async destroy() {
        return (0, bindings_1.destroyClient)(this.methodHandler);
    }
    async callMethod(method) {
        return (0, bindings_1.callClientMethodAsync)(JSON.stringify(method), this.methodHandler);
    }
    // MQTT
    async listen(topics, callback) {
        return (0, bindings_1.listenMqtt)(topics, callback, this.methodHandler);
    }
}
exports.ClientMethodHandler = ClientMethodHandler;
//# sourceMappingURL=client-method-handler.js.map