import { SecretManagerMethodHandler } from './secret-manager-method-handler';
import type { IGenerateAddressesOptions, PreparedTransactionData, LedgerNanoStatus } from '../types/client';
import { Bip44, Secp256k1EcdsaSignature, SecretManagerType } from '../types/secret_manager';
import { Ed25519Signature, HexEncodedString, TransactionPayload, Unlock } from '../types';
/** The SecretManager to interact with nodes. */
export declare class SecretManager {
    private methodHandler;
    constructor(options: SecretManagerType | SecretManagerMethodHandler);
    /** Generate ed25519 addresses */
    generateEd25519Addresses(generateAddressesOptions: IGenerateAddressesOptions): Promise<string[]>;
    /** Generate EVM addresses */
    generateEvmAddresses(generateAddressesOptions: IGenerateAddressesOptions): Promise<string[]>;
    /**
     * Store a mnemonic in the Stronghold vault
     */
    storeMnemonic(mnemonic: string): Promise<void>;
    /**
     * Sign a transaction
     */
    signTransaction(preparedTransactionData: PreparedTransactionData): Promise<TransactionPayload>;
    /**
     * Create a signature unlock using the provided `secretManager`.
     */
    signatureUnlock(transactionEssenceHash: HexEncodedString, chain: Bip44): Promise<Unlock>;
    /**
     * Signs a message with an Ed25519 private key.
     */
    signEd25519(message: HexEncodedString, chain: Bip44): Promise<Ed25519Signature>;
    /**
     * Signs a message with an Secp256k1Ecdsa private key.
     */
    signSecp256k1Ecdsa(message: HexEncodedString, chain: Bip44): Promise<Secp256k1EcdsaSignature>;
    /**
     * Get the status of a Ledger Nano
     */
    getLedgerNanoStatus(): Promise<LedgerNanoStatus>;
}
