import { HexEncodedString } from '../utils';
import { AliasId, NftId } from './id';
declare enum AddressType {
    Ed25519 = 0,
    Alias = 8,
    Nft = 16
}
declare abstract class Address {
    private type;
    constructor(type: AddressType);
    /**
     * The type of address.
     */
    getType(): AddressType;
    abstract toString(): string;
    static parse(data: any): Address;
}
/**
 * Ed25519 Address.
 */
declare class Ed25519Address extends Address {
    private pubKeyHash;
    constructor(address: HexEncodedString);
    /**
     * The public key hash.
     */
    getPubKeyHash(): HexEncodedString;
    toString(): string;
}
declare class AliasAddress extends Address {
    private aliasId;
    constructor(address: AliasId);
    /**
     * The alias id.
     */
    getAliasId(): AliasId;
    toString(): string;
}
/**
 * NFT address.
 */
declare class NftAddress extends Address {
    private nftId;
    constructor(address: NftId);
    /**
     * The NFT Id.
     */
    getNftId(): NftId;
    toString(): string;
}
declare const AddressDiscriminator: {
    property: string;
    subTypes: ({
        value: typeof Ed25519Address;
        name: any;
    } | {
        value: typeof AliasAddress;
        name: any;
    } | {
        value: typeof NftAddress;
        name: any;
    })[];
};
export { AddressDiscriminator, Address, AddressType, Ed25519Address, AliasAddress, NftAddress, };
