"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.NftAddress = exports.AliasAddress = exports.Ed25519Address = exports.AddressType = exports.Address = exports.AddressDiscriminator = void 0;
const class_transformer_1 = require("class-transformer");
var AddressType;
(function (AddressType) {
    AddressType[AddressType["Ed25519"] = 0] = "Ed25519";
    AddressType[AddressType["Alias"] = 8] = "Alias";
    AddressType[AddressType["Nft"] = 16] = "Nft";
})(AddressType || (AddressType = {}));
exports.AddressType = AddressType;
class Address {
    constructor(type) {
        this.type = type;
    }
    /**
     * The type of address.
     */
    getType() {
        return this.type;
    }
    static parse(data) {
        if (data.type == AddressType.Ed25519) {
            return (0, class_transformer_1.plainToInstance)(Ed25519Address, data);
        }
        else if (data.type == AddressType.Alias) {
            return (0, class_transformer_1.plainToInstance)(AliasAddress, data);
        }
        else if (data.type == AddressType.Nft) {
            return (0, class_transformer_1.plainToInstance)(NftAddress, data);
        }
        throw new Error('Invalid JSON');
    }
}
exports.Address = Address;
/**
 * Ed25519 Address.
 */
class Ed25519Address extends Address {
    constructor(address) {
        super(AddressType.Ed25519);
        this.pubKeyHash = address;
    }
    /**
     * The public key hash.
     */
    getPubKeyHash() {
        return this.pubKeyHash;
    }
    toString() {
        return this.getPubKeyHash();
    }
}
exports.Ed25519Address = Ed25519Address;
class AliasAddress extends Address {
    constructor(address) {
        super(AddressType.Alias);
        this.aliasId = address;
    }
    /**
     * The alias id.
     */
    getAliasId() {
        return this.aliasId;
    }
    toString() {
        return this.getAliasId();
    }
}
exports.AliasAddress = AliasAddress;
/**
 * NFT address.
 */
class NftAddress extends Address {
    constructor(address) {
        super(AddressType.Nft);
        this.nftId = address;
    }
    /**
     * The NFT Id.
     */
    getNftId() {
        return this.nftId;
    }
    toString() {
        return this.getNftId();
    }
}
exports.NftAddress = NftAddress;
const AddressDiscriminator = {
    property: 'type',
    subTypes: [
        { value: Ed25519Address, name: AddressType.Ed25519 },
        { value: AliasAddress, name: AddressType.Alias },
        { value: NftAddress, name: AddressType.Nft },
    ],
};
exports.AddressDiscriminator = AddressDiscriminator;
//# sourceMappingURL=address.js.map