"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.UTXOInput = exports.TreasuryInput = exports.Input = exports.InputType = exports.InputDiscriminator = void 0;
/**
 * All of the input types.
 */
var InputType;
(function (InputType) {
    InputType[InputType["UTXO"] = 0] = "UTXO";
    InputType[InputType["Treasury"] = 1] = "Treasury";
})(InputType || (InputType = {}));
exports.InputType = InputType;
class Input {
    constructor(type) {
        this.type = type;
    }
    /**
     * The type of input.
     */
    getType() {
        return this.type;
    }
}
exports.Input = Input;
/**
 * Treasury Input.
 */
class TreasuryInput extends Input {
    constructor(milestoneId) {
        super(InputType.Treasury);
        this.milestoneId = milestoneId;
    }
}
exports.TreasuryInput = TreasuryInput;
/**
 * UTXO Transaction Input.
 */
class UTXOInput extends Input {
    constructor(transactionId, transactionOutputIndex) {
        super(InputType.UTXO);
        this.transactionId = transactionId;
        this.transactionOutputIndex = transactionOutputIndex;
    }
}
exports.UTXOInput = UTXOInput;
const InputDiscriminator = {
    property: 'type',
    subTypes: [
        { value: TreasuryInput, name: InputType.Treasury },
        { value: UTXOInput, name: InputType.UTXO },
    ],
};
exports.InputDiscriminator = InputDiscriminator;
//# sourceMappingURL=input.js.map