"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagFeature = exports.MetadataFeature = exports.IssuerFeature = exports.SenderFeature = exports.FeatureType = exports.Feature = exports.FeatureDiscriminator = void 0;
/**
 * All of the feature block types.
 */
var FeatureType;
(function (FeatureType) {
    FeatureType[FeatureType["Sender"] = 0] = "Sender";
    FeatureType[FeatureType["Issuer"] = 1] = "Issuer";
    FeatureType[FeatureType["Metadata"] = 2] = "Metadata";
    FeatureType[FeatureType["Tag"] = 3] = "Tag";
})(FeatureType || (FeatureType = {}));
exports.FeatureType = FeatureType;
class Feature {
    constructor(type) {
        this.type = type;
    }
    /**
     * The type of feature.
     */
    getType() {
        return this.type;
    }
}
exports.Feature = Feature;
/**
 * Sender feature.
 */
class SenderFeature extends Feature {
    constructor(sender) {
        super(FeatureType.Sender);
        this.address = sender;
    }
    /**
     * The address.
     */
    getSender() {
        return this.address;
    }
}
exports.SenderFeature = SenderFeature;
/**
 * Issuer feature.
 */
class IssuerFeature extends Feature {
    constructor(issuer) {
        super(FeatureType.Issuer);
        this.address = issuer;
    }
    /**
     * The address.
     */
    getIssuer() {
        return this.address;
    }
}
exports.IssuerFeature = IssuerFeature;
/**
 * Metadata feature.
 */
class MetadataFeature extends Feature {
    constructor(data) {
        super(FeatureType.Metadata);
        this.data = data;
    }
    /**
     * Defines metadata (arbitrary binary data) that will be stored in the output.
     */
    getData() {
        return this.data;
    }
}
exports.MetadataFeature = MetadataFeature;
/**
 * Tag feature.
 */
class TagFeature extends Feature {
    constructor(tag) {
        super(FeatureType.Tag);
        this.tag = tag;
    }
    /**
     * Defines a tag for the data.
     */
    getTag() {
        return this.tag;
    }
}
exports.TagFeature = TagFeature;
const FeatureDiscriminator = {
    property: 'type',
    subTypes: [
        { value: SenderFeature, name: FeatureType.Sender },
        { value: IssuerFeature, name: FeatureType.Issuer },
        { value: MetadataFeature, name: FeatureType.Metadata },
        { value: TagFeature, name: FeatureType.Tag },
    ],
};
exports.FeatureDiscriminator = FeatureDiscriminator;
//# sourceMappingURL=feature.js.map