"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleTokenScheme = exports.TokenSchemeType = exports.TokenScheme = exports.TokenSchemeDiscriminator = void 0;
const hex_encoding_1 = require("../../utils/hex-encoding");
var TokenSchemeType;
(function (TokenSchemeType) {
    TokenSchemeType[TokenSchemeType["Simple"] = 0] = "Simple";
})(TokenSchemeType || (TokenSchemeType = {}));
exports.TokenSchemeType = TokenSchemeType;
class TokenScheme {
    constructor(type) {
        this.type = type;
    }
    /**
     * The type of token scheme.
     */
    getType() {
        return this.type;
    }
}
exports.TokenScheme = TokenScheme;
/**
 * Simple token scheme.
 */
class SimpleTokenScheme extends TokenScheme {
    constructor(mintedTokens, meltedTokens, maximumSupply) {
        super(TokenSchemeType.Simple);
        if (typeof mintedTokens === 'bigint') {
            this.mintedTokens = mintedTokens;
        }
        else if (mintedTokens) {
            this.mintedTokens = (0, hex_encoding_1.hexToBigInt)(mintedTokens);
        }
        else {
            this.mintedTokens = BigInt(0);
        }
        if (typeof meltedTokens === 'bigint') {
            this.meltedTokens = meltedTokens;
        }
        else if (meltedTokens) {
            this.meltedTokens = (0, hex_encoding_1.hexToBigInt)(meltedTokens);
        }
        else {
            this.meltedTokens = BigInt(0);
        }
        if (typeof maximumSupply === 'bigint') {
            this.maximumSupply = maximumSupply;
        }
        else if (maximumSupply) {
            this.maximumSupply = (0, hex_encoding_1.hexToBigInt)(maximumSupply);
        }
        else {
            this.maximumSupply = BigInt(0);
        }
    }
    /**
     * Amount of tokens minted.
     */
    getMintedTokens() {
        return this.mintedTokens;
    }
    /**
     * Amount of tokens melted.
     */
    getMeltedTokens() {
        return this.meltedTokens;
    }
    /**
     * Maximum supply of tokens controlled.
     */
    getMaximumSupply() {
        return this.maximumSupply;
    }
}
exports.SimpleTokenScheme = SimpleTokenScheme;
const TokenSchemeDiscriminator = {
    property: 'type',
    subTypes: [
        { value: SimpleTokenScheme, name: TokenSchemeType.Simple },
    ],
};
exports.TokenSchemeDiscriminator = TokenSchemeDiscriminator;
//# sourceMappingURL=token-scheme.js.map