"use strict";
// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImmutableAliasAddressUnlockCondition = exports.GovernorAddressUnlockCondition = exports.StateControllerAddressUnlockCondition = exports.ExpirationUnlockCondition = exports.TimelockUnlockCondition = exports.StorageDepositReturnUnlockCondition = exports.AddressUnlockCondition = exports.UnlockConditionType = exports.UnlockCondition = exports.UnlockConditionDiscriminator = void 0;
const class_transformer_1 = require("class-transformer");
const address_1 = require("../address");
/**
 * All of the unlock condition types.
 */
var UnlockConditionType;
(function (UnlockConditionType) {
    UnlockConditionType[UnlockConditionType["Address"] = 0] = "Address";
    UnlockConditionType[UnlockConditionType["StorageDepositReturn"] = 1] = "StorageDepositReturn";
    UnlockConditionType[UnlockConditionType["Timelock"] = 2] = "Timelock";
    UnlockConditionType[UnlockConditionType["Expiration"] = 3] = "Expiration";
    UnlockConditionType[UnlockConditionType["StateControllerAddress"] = 4] = "StateControllerAddress";
    UnlockConditionType[UnlockConditionType["GovernorAddress"] = 5] = "GovernorAddress";
    UnlockConditionType[UnlockConditionType["ImmutableAliasAddress"] = 6] = "ImmutableAliasAddress";
})(UnlockConditionType || (UnlockConditionType = {}));
exports.UnlockConditionType = UnlockConditionType;
class UnlockCondition {
    constructor(type) {
        this.type = type;
    }
    /**
     * The type of unlock condition.
     */
    getType() {
        return this.type;
    }
    static parse(data) {
        if (data.type == UnlockConditionType.Address) {
            return (0, class_transformer_1.plainToInstance)(AddressUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.StorageDepositReturn) {
            return (0, class_transformer_1.plainToInstance)(StorageDepositReturnUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.Timelock) {
            return (0, class_transformer_1.plainToInstance)(TimelockUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.Expiration) {
            return (0, class_transformer_1.plainToInstance)(ExpirationUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.StateControllerAddress) {
            return (0, class_transformer_1.plainToInstance)(StateControllerAddressUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.GovernorAddress) {
            return (0, class_transformer_1.plainToInstance)(GovernorAddressUnlockCondition, data);
        }
        else if (data.type == UnlockConditionType.ImmutableAliasAddress) {
            return (0, class_transformer_1.plainToInstance)(ImmutableAliasAddressUnlockCondition, data);
        }
        throw new Error('Invalid JSON');
    }
}
exports.UnlockCondition = UnlockCondition;
class AddressUnlockCondition extends UnlockCondition /*implements IAddressUnlockCondition*/ {
    constructor(address) {
        super(UnlockConditionType.Address);
        this.address = address;
    }
    /**
     * The address.
     */
    getAddress() {
        return this.address;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], AddressUnlockCondition.prototype, "address", void 0);
exports.AddressUnlockCondition = AddressUnlockCondition;
/**
 * Storage Deposit Return Unlock Condition.
 */
class StorageDepositReturnUnlockCondition extends UnlockCondition /*implements IStorageDepositReturnUnlockCondition*/ {
    constructor(returnAddress, amount) {
        super(UnlockConditionType.StorageDepositReturn);
        if (typeof amount == 'bigint') {
            this.amount = amount.toString(10);
        }
        else {
            this.amount = amount;
        }
        this.returnAddress = returnAddress;
    }
    /**
     * Amount of tokens the consuming transaction must deposit to the address defined in return address.
     */
    getAmount() {
        return BigInt(this.amount);
    }
    /**
     * The return address.
     */
    getReturnAddress() {
        return this.returnAddress;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], StorageDepositReturnUnlockCondition.prototype, "returnAddress", void 0);
exports.StorageDepositReturnUnlockCondition = StorageDepositReturnUnlockCondition;
/**
 * Timelock Unlock Condition.
 */
class TimelockUnlockCondition extends UnlockCondition /*implements ITimelockUnlockCondition*/ {
    constructor(unixTime) {
        super(UnlockConditionType.Timelock);
        this.unixTime = unixTime;
    }
    /**
     * Unix time (seconds since Unix epoch) starting from which the output can be consumed.
     */
    getUnixTime() {
        return this.unixTime;
    }
}
exports.TimelockUnlockCondition = TimelockUnlockCondition;
class ExpirationUnlockCondition extends UnlockCondition /*implements IExpirationUnlockCondition*/ {
    constructor(returnAddress, unixTime) {
        super(UnlockConditionType.Expiration);
        this.returnAddress = returnAddress;
        this.unixTime = unixTime;
    }
    /**
     * Before this unix time, the condition is allowed to unlock the output,
     * after that only the address defined in return address.
     */
    getUnixTime() {
        return this.unixTime;
    }
    /**
     * The return address.
     */
    getReturnAddress() {
        return this.returnAddress;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], ExpirationUnlockCondition.prototype, "returnAddress", void 0);
exports.ExpirationUnlockCondition = ExpirationUnlockCondition;
/**
 * State Controller Address Unlock Condition.
 */
class StateControllerAddressUnlockCondition extends UnlockCondition /*implements IStateControllerAddressUnlockCondition*/ {
    constructor(address) {
        super(UnlockConditionType.StateControllerAddress);
        this.address = address;
    }
    /**
     * The address.
     */
    getAddress() {
        return this.address;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], StateControllerAddressUnlockCondition.prototype, "address", void 0);
exports.StateControllerAddressUnlockCondition = StateControllerAddressUnlockCondition;
/**
 * Governor Unlock Condition.
 */
class GovernorAddressUnlockCondition extends UnlockCondition /*implements IGovernorAddressUnlockCondition*/ {
    constructor(address) {
        super(UnlockConditionType.GovernorAddress);
        this.address = address;
    }
    /**
     * The address.
     */
    getAddress() {
        return this.address;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], GovernorAddressUnlockCondition.prototype, "address", void 0);
exports.GovernorAddressUnlockCondition = GovernorAddressUnlockCondition;
/**
 * Immutable Alias Unlock Condition.
 */
class ImmutableAliasAddressUnlockCondition extends UnlockCondition /*implements IImmutableAliasAddressUnlockCondition*/ {
    constructor(address) {
        super(UnlockConditionType.ImmutableAliasAddress);
        this.address = address;
    }
    /**
     * The address.
     */
    getAddress() {
        return this.address;
    }
}
__decorate([
    (0, class_transformer_1.Type)(() => address_1.Address, {
        discriminator: address_1.AddressDiscriminator,
    })
], ImmutableAliasAddressUnlockCondition.prototype, "address", void 0);
exports.ImmutableAliasAddressUnlockCondition = ImmutableAliasAddressUnlockCondition;
const UnlockConditionDiscriminator = {
    property: 'type',
    subTypes: [
        {
            value: AddressUnlockCondition,
            name: UnlockConditionType.Address,
        },
        {
            value: StorageDepositReturnUnlockCondition,
            name: UnlockConditionType.StorageDepositReturn,
        },
        {
            value: TimelockUnlockCondition,
            name: UnlockConditionType.Timelock,
        },
        {
            value: ExpirationUnlockCondition,
            name: UnlockConditionType.Expiration,
        },
        {
            value: StateControllerAddressUnlockCondition,
            name: UnlockConditionType.StateControllerAddress,
        },
        {
            value: GovernorAddressUnlockCondition,
            name: UnlockConditionType.GovernorAddress,
        },
        {
            value: ImmutableAliasAddressUnlockCondition,
            name: UnlockConditionType.ImmutableAliasAddress,
        },
    ],
};
exports.UnlockConditionDiscriminator = UnlockConditionDiscriminator;
//# sourceMappingURL=unlock-condition.js.map