// Copyright 2021-2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { ClientMethodHandler } from './client-method-handler';
import { PreparedTransactionData, } from '../types/client';
import { AliasOutput, BasicOutput, FoundryOutput, NftOutput, Block, UnlockCondition, TransactionPayload, MilestonePayload, Output, } from '../types/block';
import { UTXOInput, } from '../types';
import { OutputResponse, ReceiptsResponse, } from '../types/models/api';
import { plainToInstance } from 'class-transformer';
/** The Client to interact with nodes. */
var Client = /** @class */ (function () {
    function Client(options) {
        this.methodHandler = new ClientMethodHandler(options);
    }
    Client.prototype.destroy = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.methodHandler.destroy()];
            });
        });
    };
    /**
     * Returns the node information together with the url of the used node
     * @returns { Promise<INodeInfoWrapper> }.
     */
    Client.prototype.getInfo = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getInfo'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Gets the network related information such as network_id and min_pow_score
     */
    Client.prototype.getNetworkInfo = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getNetworkInfo'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /** Fetch basic output IDs based on query parameters */
    Client.prototype.basicOutputIds = function (queryParameters) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'basicOutputIds',
                            data: {
                                queryParameters: queryParameters
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /** Get output from a known outputID */
    Client.prototype.getOutput = function (outputId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getOutput',
                            data: {
                                outputId: outputId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(OutputResponse, parsed.payload)];
                }
            });
        });
    };
    /** Fetch OutputResponse from provided OutputIds (requests are sent in parallel) */
    Client.prototype.getOutputs = function (outputIds) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getOutputs',
                            data: {
                                outputIds: outputIds
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(OutputResponse, parsed.payload)];
                }
            });
        });
    };
    /** Build and post a block */
    Client.prototype.buildAndPostBlock = function (secretManager, options) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (options &&
                            options.output &&
                            typeof options.output.amount === 'bigint') {
                            options.output.amount = options.output.amount.toString(10);
                        }
                        if (options &&
                            options.outputHex &&
                            typeof options.outputHex.amount === 'bigint') {
                            options.outputHex.amount = options.outputHex.amount.toString(10);
                        }
                        return [4 /*yield*/, this.methodHandler.callMethod({
                                name: 'buildAndPostBlock',
                                data: {
                                    secretManager: secretManager,
                                    options: options
                                }
                            })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Returns tips that are ideal for attaching a block.
     * The tips can be considered as non-lazy and are therefore ideal for attaching a block.
     */
    Client.prototype.getTips = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getTips'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Post block in JSON format, returns the block ID.
     */
    Client.prototype.postBlock = function (block) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'postBlock',
                            data: {
                                block: block
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get block as JSON.
     */
    Client.prototype.getBlock = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getBlock',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(Block, parsed.payload)];
                }
            });
        });
    };
    /**
     * Get block metadata.
     */
    Client.prototype.getBlockMetadata = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getBlockMetadata',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Find inputs from addresses for a provided amount (useful for offline signing)
     */
    Client.prototype.findInputs = function (addresses, amount) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'findInputs',
                            data: {
                                addresses: addresses,
                                amount: Number(amount)
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(UTXOInput, parsed.payload)];
                }
            });
        });
    };
    /**
     * Prepare a transaction for signing
     */
    Client.prototype.prepareTransaction = function (secretManager, options) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'prepareTransaction',
                            data: {
                                secretManager: secretManager,
                                options: options
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(PreparedTransactionData, parsed.payload)];
                }
            });
        });
    };
    /**
     * Sign a transaction
     */
    Client.prototype.signTransaction = function (secretManager, preparedTransactionData) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'signTransaction',
                            data: {
                                secretManager: secretManager,
                                preparedTransactionData: preparedTransactionData
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(TransactionPayload, parsed.payload)];
                }
            });
        });
    };
    /**
     * Create a signature unlock using the provided `secretManager`.
     */
    Client.prototype.signatureUnlock = function (secretManager, transactionEssenceHash, chain) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'signatureUnlock',
                            data: {
                                secretManager: secretManager,
                                transactionEssenceHash: transactionEssenceHash,
                                chain: chain
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, UnlockCondition.parse(JSON.parse(response).payload)];
                }
            });
        });
    };
    /**
     * Submit a payload in a block
     */
    Client.prototype.postBlockPayload = function (payload) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'postBlockPayload',
                            data: {
                                payload: payload
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Get a node candidate from the healthy node pool.
     */
    Client.prototype.getNode = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getNode'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get the network id of the node we're connecting to.
     */
    Client.prototype.getNetworkId = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getNetworkId'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Returns the bech32_hrp.
     */
    Client.prototype.getBech32Hrp = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getBech32Hrp'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Returns the min PoW score.
     */
    Client.prototype.getMinPowScore = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getMinPowScore'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Returns the tips interval.
     */
    Client.prototype.getTipsInterval = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getTipsInterval'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Returns the token supply.
     */
    Client.prototype.getTokenSupply = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.getProtocolParameters()];
                    case 1: return [2 /*return*/, (_a.sent()).tokenSupply];
                }
            });
        });
    };
    /**
     * Returns the protocol parameters.
     */
    Client.prototype.getProtocolParameters = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getProtocolParameters'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Returns if local pow should be used or not.
     */
    Client.prototype.getLocalPow = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getLocalPow'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get fallback to local proof of work timeout.
     */
    Client.prototype.getFallbackToLocalPow = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getFallbackToLocalPow'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get health of node by input url.
     */
    Client.prototype.getHealth = function (url) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getHealth',
                            data: {
                                url: url
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get info of node with input url.
     */
    Client.prototype.getNodeInfo = function (url, auth) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getNodeInfo',
                            data: {
                                url: url,
                                auth: auth
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get peers.
     */
    Client.prototype.getPeers = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getPeers'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Post block as raw bytes, returns the block ID.
     */
    Client.prototype.postBlockRaw = function (block) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'postBlockRaw',
                            data: {
                                block: block
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get block as raw bytes.
     */
    Client.prototype.getBlockRaw = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getBlockRaw',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Look up a milestone by a given milestone index.
     */
    Client.prototype.getMilestoneById = function (milestoneId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getMilestoneById',
                            data: {
                                milestoneId: milestoneId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(MilestonePayload, parsed.payload)];
                }
            });
        });
    };
    /**
     * Returns all UTXO changes that happened at a specific milestone.
     */
    Client.prototype.getUtxoChangesById = function (milestoneId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getUtxoChangesById',
                            data: {
                                milestoneId: milestoneId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Look up a milestone by a given milestone index.
     */
    Client.prototype.getMilestoneByIndex = function (index) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getMilestoneByIndex',
                            data: {
                                index: index
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(MilestonePayload, parsed.payload)];
                }
            });
        });
    };
    /**
     * Returns all UTXO changes that happened at a specific milestone.
     */
    Client.prototype.getUtxoChangesByIndex = function (index) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getUtxoChangesByIndex',
                            data: {
                                index: index
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Get receipts.
     */
    Client.prototype.getReceipts = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getReceipts'
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(ReceiptsResponse, parsed.payload)];
                }
            });
        });
    };
    /**
     * Get the receipts by the given milestone index.
     */
    Client.prototype.getReceiptsMigratedAt = function (milestoneIndex) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getReceiptsMigratedAt',
                            data: {
                                milestoneIndex: milestoneIndex
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(ReceiptsResponse, parsed.payload)];
                }
            });
        });
    };
    /**
     * Get the treasury output.
     */
    Client.prototype.getTreasury = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getTreasury'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, Output.parse(JSON.parse(response).payload)];
                }
            });
        });
    };
    /**
     * Returns the included block of the transaction.
     */
    Client.prototype.getIncludedBlock = function (transactionId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getIncludedBlock',
                            data: {
                                transactionId: transactionId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(Block, parsed.payload)];
                }
            });
        });
    };
    /**
     * Returns the metadata of the included block of the transaction.
     */
    Client.prototype.getIncludedBlockMetadata = function (transactionId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getIncludedBlockMetadata',
                            data: {
                                transactionId: transactionId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(Block, parsed.payload)];
                }
            });
        });
    };
    /**
     * Transforms a hex encoded address to a bech32 encoded address.
     */
    Client.prototype.hexToBech32 = function (hex, bech32Hrp) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'hexToBech32',
                            data: {
                                hex: hex,
                                bech32Hrp: bech32Hrp
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Transforms an alias id to a bech32 encoded address.
     */
    Client.prototype.aliasIdToBech32 = function (aliasId, bech32Hrp) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'aliasIdToBech32',
                            data: {
                                aliasId: aliasId,
                                bech32Hrp: bech32Hrp
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Transforms an nft id to a bech32 encoded address.
     */
    Client.prototype.nftIdToBech32 = function (nftId, bech32Hrp) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'nftIdToBech32',
                            data: {
                                nftId: nftId,
                                bech32Hrp: bech32Hrp
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Transforms a hex encoded public key to a bech32 encoded address.
     */
    Client.prototype.hexPublicKeyToBech32Address = function (hex, bech32Hrp) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'hexPublicKeyToBech32Address',
                            data: {
                                hex: hex,
                                bech32Hrp: bech32Hrp
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch alias output IDs
     */
    Client.prototype.aliasOutputIds = function (queryParameters) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'aliasOutputIds',
                            data: {
                                queryParameters: queryParameters
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch alias output ID
     */
    Client.prototype.aliasOutputId = function (aliasId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'aliasOutputId',
                            data: {
                                aliasId: aliasId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch NFT output IDs
     */
    Client.prototype.nftOutputIds = function (queryParameters) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'nftOutputIds',
                            data: {
                                queryParameters: queryParameters
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch NFT output ID
     */
    Client.prototype.nftOutputId = function (nftId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'nftOutputId',
                            data: {
                                nftId: nftId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch Foundry Output IDs
     */
    Client.prototype.foundryOutputIds = function (queryParameters) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'foundryOutputIds',
                            data: {
                                queryParameters: queryParameters
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Fetch Foundry Output ID
     */
    Client.prototype.foundryOutputId = function (foundryId) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'foundryOutputId',
                            data: {
                                foundryId: foundryId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Try to get OutputResponse from provided OutputIds (requests are sent
     * in parallel and errors are ignored, can be useful for spent outputs)
     */
    Client.prototype.getOutputsIgnoreErrors = function (outputIds) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'getOutputsIgnoreErrors',
                            data: {
                                outputIds: outputIds
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(OutputResponse, parsed.payload)];
                }
            });
        });
    };
    /**
     * Find all blocks by provided block IDs.
     */
    Client.prototype.findBlocks = function (blockIds) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'findBlocks',
                            data: {
                                blockIds: blockIds
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(Block, parsed.payload)];
                }
            });
        });
    };
    /**
     * Retries (promotes or reattaches) a block for provided block id. Block should be
     * retried only if they are valid and haven't been confirmed for a while.
     */
    Client.prototype.retry = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'retry',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Retries (promotes or reattaches) a block for provided block id until it's included (referenced by a
     * milestone). Default interval is 5 seconds and max attempts is 40. Returns the included block at first
     * position and additional reattached blocks
     */
    Client.prototype.retryUntilIncluded = function (blockId, interval, maxAttempts) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, arr;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'retryUntilIncluded',
                            data: {
                                blockId: blockId,
                                interval: interval,
                                maxAttempts: maxAttempts
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        arr = [];
                        parsed.payload.forEach(function (payload) {
                            arr.push([payload[0], plainToInstance(Block, payload[1])]);
                        });
                        return [2 /*return*/, arr];
                }
            });
        });
    };
    /**
     * Function to consolidate all funds from a range of addresses to the address with the lowest index in that range
     * Returns the address to which the funds got consolidated, if any were available
     */
    Client.prototype.consolidateFunds = function (secretManager, generateAddressesOptions) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'consolidateFunds',
                            data: {
                                secretManager: secretManager,
                                generateAddressesOptions: generateAddressesOptions
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Reattaches blocks for provided block id. Blocks can be reattached only if they are valid and haven't been
     * confirmed for a while.
     */
    Client.prototype.reattach = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'reattach',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Reattach a block without checking if it should be reattached
     */
    Client.prototype.reattachUnchecked = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'reattachUnchecked',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Promotes a block. The method should validate if a promotion is necessary through get_block. If not, the
     * method should error out and should not allow unnecessary promotions.
     */
    Client.prototype.promote = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'promote',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Promote a block without checking if it should be promoted
     */
    Client.prototype.promoteUnchecked = function (blockId) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed, block;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'promoteUnchecked',
                            data: {
                                blockId: blockId
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        block = plainToInstance(Block, parsed.payload[1]);
                        return [2 /*return*/, [parsed.payload[0], block]];
                }
            });
        });
    };
    /**
     * Returns the unhealthy nodes.
     */
    Client.prototype.unhealthyNodes = function () {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'unhealthyNodes'
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Build a Basic Output.
     */
    Client.prototype.buildBasicOutput = function (params) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (params.amount && typeof params.amount === 'bigint') {
                            params.amount = params.amount.toString(10);
                        }
                        return [4 /*yield*/, this.methodHandler.callMethod({
                                name: 'buildBasicOutput',
                                data: params
                            })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(BasicOutput, parsed.payload)];
                }
            });
        });
    };
    /**
     * Build an Alias Output.
     */
    Client.prototype.buildAliasOutput = function (params) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (params.amount && typeof params.amount === 'bigint') {
                            params.amount = params.amount.toString(10);
                        }
                        return [4 /*yield*/, this.methodHandler.callMethod({
                                name: 'buildAliasOutput',
                                data: params
                            })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(AliasOutput, parsed.payload)];
                }
            });
        });
    };
    /**
     * Build a Foundry Output.
     */
    Client.prototype.buildFoundryOutput = function (params) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (params.amount && typeof params.amount === 'bigint') {
                            params.amount = params.amount.toString(10);
                        }
                        return [4 /*yield*/, this.methodHandler.callMethod({
                                name: 'buildFoundryOutput',
                                data: params
                            })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(FoundryOutput, parsed.payload)];
                }
            });
        });
    };
    /**
     * Build an Nft Output.
     */
    Client.prototype.buildNftOutput = function (params) {
        return __awaiter(this, void 0, void 0, function () {
            var response, parsed;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (params.amount && typeof params.amount === 'bigint') {
                            params.amount = params.amount.toString(10);
                        }
                        return [4 /*yield*/, this.methodHandler.callMethod({
                                name: 'buildNftOutput',
                                data: params
                            })];
                    case 1:
                        response = _a.sent();
                        parsed = JSON.parse(response);
                        return [2 /*return*/, plainToInstance(NftOutput, parsed.payload)];
                }
            });
        });
    };
    /**
     * Listen to MQTT topics.
     */
    Client.prototype.listenMqtt = function (topics, callback) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.methodHandler.listen(topics, callback)];
            });
        });
    };
    /**
     * Stop listening for provided MQTT topics.
     */
    Client.prototype.clearMqttListeners = function (topics) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'clearListeners',
                            data: {
                                topics: topics
                            }
                        })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Calculate the minimum required storage deposit for an output.
     * @param output output to calculate the deposit amount for.
     * @returns The amount.
     */
    Client.prototype.minimumRequiredStorageDeposit = function (output) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'minimumRequiredStorageDeposit',
                            data: {
                                output: output
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Request funds from a faucet, for example `https://faucet.testnet.shimmer.network/api/enqueue` or `http://localhost:8091/api/enqueue`.
     */
    Client.prototype.requestFundsFromFaucet = function (url, address) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'requestFundsFromFaucet',
                            data: { url: url, address: address }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    /**
     * Extension method which provides request methods for plugins.
     * @param basePluginPath The base path for the plugin eg indexer/v1/ .
     * @param method The http method.
     * @param endpoint The path for the plugin request.
     * @param queryParams Additional query params for the request.
     * @param request The request object.
     * @returns The response json.
     */
    Client.prototype.callPluginRoute = function (basePluginPath, method, endpoint, queryParams, request) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.methodHandler.callMethod({
                            name: 'callPluginRoute',
                            data: {
                                basePluginPath: basePluginPath,
                                method: method,
                                endpoint: endpoint,
                                queryParams: queryParams !== null && queryParams !== void 0 ? queryParams : [],
                                request: request
                            }
                        })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, JSON.parse(response).payload];
                }
            });
        });
    };
    return Client;
}());
export { Client };
//# sourceMappingURL=client.js.map