import { HexEncodedString } from '../../utils';
/**
 * All of the input types.
 */
declare enum InputType {
    UTXO = 0,
    Treasury = 1
}
declare abstract class Input {
    private type;
    constructor(type: InputType);
    /**
     * The type of input.
     */
    getType(): InputType;
}
/**
 * Treasury Input.
 */
declare class TreasuryInput extends Input {
    /**
     * The milestone id of the input.
     */
    milestoneId: HexEncodedString;
    constructor(milestoneId: HexEncodedString);
}
/**
 * UTXO Transaction Input.
 */
declare class UTXOInput extends Input {
    /**
     * The transaction Id.
     */
    transactionId: HexEncodedString;
    /**
     * The output index.
     */
    transactionOutputIndex: number;
    constructor(transactionId: HexEncodedString, transactionOutputIndex: number);
}
declare const InputDiscriminator: {
    property: string;
    subTypes: ({
        value: typeof TreasuryInput;
        name: any;
    } | {
        value: typeof UTXOInput;
        name: any;
    })[];
};
export { InputDiscriminator, InputType, Input, TreasuryInput, UTXOInput };
