import { Address } from '../address';
/**
 * All of the feature block types.
 */
declare enum FeatureType {
    Sender = 0,
    Issuer = 1,
    Metadata = 2,
    Tag = 3
}
declare abstract class Feature {
    private type;
    constructor(type: FeatureType);
    /**
     * The type of feature.
     */
    getType(): FeatureType;
}
/**
 * Sender feature.
 */
declare class SenderFeature extends Feature {
    private address;
    constructor(sender: Address);
    /**
     * The address.
     */
    getSender(): Address;
}
/**
 * Issuer feature.
 */
declare class IssuerFeature extends Feature {
    private address;
    constructor(issuer: Address);
    /**
     * The address.
     */
    getIssuer(): Address;
}
/**
 * Metadata feature.
 */
declare class MetadataFeature extends Feature {
    private data;
    constructor(data: string);
    /**
     * Defines metadata (arbitrary binary data) that will be stored in the output.
     */
    getData(): string;
}
/**
 * Tag feature.
 */
declare class TagFeature extends Feature {
    private tag;
    constructor(tag: string);
    /**
     * Defines a tag for the data.
     */
    getTag(): string;
}
declare const FeatureDiscriminator: {
    property: string;
    subTypes: ({
        value: typeof SenderFeature;
        name: any;
    } | {
        value: typeof IssuerFeature;
        name: any;
    } | {
        value: typeof MetadataFeature;
        name: any;
    } | {
        value: typeof TagFeature;
        name: any;
    })[];
};
export { FeatureDiscriminator, Feature, FeatureType, SenderFeature, IssuerFeature, MetadataFeature, TagFeature, };
