// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * All of the feature block types.
 */
var FeatureType;
(function (FeatureType) {
    FeatureType[FeatureType["Sender"] = 0] = "Sender";
    FeatureType[FeatureType["Issuer"] = 1] = "Issuer";
    FeatureType[FeatureType["Metadata"] = 2] = "Metadata";
    FeatureType[FeatureType["Tag"] = 3] = "Tag";
})(FeatureType || (FeatureType = {}));
var Feature = /** @class */ (function () {
    function Feature(type) {
        this.type = type;
    }
    /**
     * The type of feature.
     */
    Feature.prototype.getType = function () {
        return this.type;
    };
    return Feature;
}());
/**
 * Sender feature.
 */
var SenderFeature = /** @class */ (function (_super) {
    __extends(SenderFeature, _super);
    function SenderFeature(sender) {
        var _this = _super.call(this, FeatureType.Sender) || this;
        _this.address = sender;
        return _this;
    }
    /**
     * The address.
     */
    SenderFeature.prototype.getSender = function () {
        return this.address;
    };
    return SenderFeature;
}(Feature));
/**
 * Issuer feature.
 */
var IssuerFeature = /** @class */ (function (_super) {
    __extends(IssuerFeature, _super);
    function IssuerFeature(issuer) {
        var _this = _super.call(this, FeatureType.Issuer) || this;
        _this.address = issuer;
        return _this;
    }
    /**
     * The address.
     */
    IssuerFeature.prototype.getIssuer = function () {
        return this.address;
    };
    return IssuerFeature;
}(Feature));
/**
 * Metadata feature.
 */
var MetadataFeature = /** @class */ (function (_super) {
    __extends(MetadataFeature, _super);
    function MetadataFeature(data) {
        var _this = _super.call(this, FeatureType.Metadata) || this;
        _this.data = data;
        return _this;
    }
    /**
     * Defines metadata (arbitrary binary data) that will be stored in the output.
     */
    MetadataFeature.prototype.getData = function () {
        return this.data;
    };
    return MetadataFeature;
}(Feature));
/**
 * Tag feature.
 */
var TagFeature = /** @class */ (function (_super) {
    __extends(TagFeature, _super);
    function TagFeature(tag) {
        var _this = _super.call(this, FeatureType.Tag) || this;
        _this.tag = tag;
        return _this;
    }
    /**
     * Defines a tag for the data.
     */
    TagFeature.prototype.getTag = function () {
        return this.tag;
    };
    return TagFeature;
}(Feature));
var FeatureDiscriminator = {
    property: 'type',
    subTypes: [
        { value: SenderFeature, name: FeatureType.Sender },
        { value: IssuerFeature, name: FeatureType.Issuer },
        { value: MetadataFeature, name: FeatureType.Metadata },
        { value: TagFeature, name: FeatureType.Tag },
    ]
};
export { FeatureDiscriminator, Feature, FeatureType, SenderFeature, IssuerFeature, MetadataFeature, TagFeature, };
//# sourceMappingURL=feature.js.map