// Copyright 2023 IOTA Stiftung
// SPDX-License-Identifier: Apache-2.0
import { callUtilsMethod } from '../bindings';
import { Address, hexToBigInt, } from '../types';
/** Utils class for utils. */
var Utils = /** @class */ (function () {
    function Utils() {
    }
    /**
     * Generates a new mnemonic.
     */
    Utils.generateMnemonic = function () {
        return callUtilsMethod({
            name: 'generateMnemonic'
        });
    };
    /**
     * Returns a hex encoded seed for a mnemonic.
     */
    Utils.mnemonicToHexSeed = function (mnemonic) {
        return callUtilsMethod({
            name: 'mnemonicToHexSeed',
            data: {
                mnemonic: mnemonic
            }
        });
    };
    /**
     * Computes the alias id for the given alias output id.
     */
    Utils.computeAliasId = function (outputId) {
        return callUtilsMethod({
            name: 'computeAliasId',
            data: {
                outputId: outputId
            }
        });
    };
    /**
     * Computes the foundry id.
     */
    Utils.computeFoundryId = function (aliasId, serialNumber, tokenSchemeKind) {
        return callUtilsMethod({
            name: 'computeFoundryId',
            data: {
                aliasId: aliasId,
                serialNumber: serialNumber,
                tokenSchemeKind: tokenSchemeKind
            }
        });
    };
    /**
     * Computes the NFT id for the given NFT output id.
     */
    Utils.computeNftId = function (outputId) {
        return callUtilsMethod({
            name: 'computeNftId',
            data: {
                outputId: outputId
            }
        });
    };
    /**
     * Computes the inputCommitment from the output objects that are used as inputs to fund the transaction.
     * @param inputs The output objects used as inputs for the transaction.
     * @returns The inputs commitment.
     */
    Utils.computeInputsCommitment = function (inputs) {
        return callUtilsMethod({
            name: 'computeInputsCommitment',
            data: {
                inputs: inputs
            }
        });
    };
    /**
     * Computes the output ID from transaction id and output index.
     * @param transactionId The id of the transaction.
     * @param outputIndex The index of the output.
     * @returns The output id.
     */
    Utils.computeOutputId = function (id, index) {
        return callUtilsMethod({
            name: 'computeOutputId',
            data: {
                id: id,
                index: index
            }
        });
    };
    /**
     * Computes the required storage deposit of an output.
     * @param output The output.
     * @param rentStructure Rent cost of objects which take node resources.
     * @returns The required storage deposit.
     */
    Utils.computeStorageDeposit = function (output, rentStructure) {
        var depositHex = callUtilsMethod({
            name: 'computeStorageDeposit',
            data: {
                output: output,
                rentStructure: rentStructure
            }
        });
        return hexToBigInt(depositHex);
    };
    /**
     * Computes a tokenId from the aliasId, serial number and token scheme type.
     * @param aliasId The alias that controls the foundry.
     * @param serialNumber The serial number of the foundry.
     * @param tokenSchemeType The tokenSchemeType of the foundry.
     * @returns The tokenId.
     */
    Utils.computeTokenId = function (aliasId, serialNumber, tokenSchemeType) {
        return callUtilsMethod({
            name: 'computeTokenId',
            data: {
                aliasId: aliasId,
                serialNumber: serialNumber,
                tokenSchemeType: tokenSchemeType
            }
        });
    };
    /**
     * Returns a valid Address parsed from a String.
     */
    Utils.parseBech32Address = function (address) {
        var addr = callUtilsMethod({
            name: 'parseBech32Address',
            data: {
                address: address
            }
        });
        return Address.parse(addr);
    };
    /**
     * Returns a block ID (Blake2b256 hash of the block bytes)
     */
    Utils.blockId = function (block) {
        return callUtilsMethod({
            name: 'blockId',
            data: {
                block: block
            }
        });
    };
    /**
     * Returns a Milestone ID (Blake2b256 hash of the milestone essence)
     */
    Utils.milestoneId = function (payload) {
        return callUtilsMethod({
            name: 'milestoneId',
            data: {
                payload: payload
            }
        });
    };
    /**
     * Returns the transaction ID (Blake2b256 hash of the provided transaction payload)
     * @param payload The transaction payload.
     * @returns The transaction id.
     */
    Utils.transactionId = function (payload) {
        return callUtilsMethod({
            name: 'transactionId',
            data: {
                payload: payload
            }
        });
    };
    /**
     * Transforms bech32 to hex.
     */
    Utils.bech32ToHex = function (bech32) {
        return callUtilsMethod({
            name: 'bech32ToHex',
            data: {
                bech32: bech32
            }
        });
    };
    /**
     * Transforms a hex encoded address to a bech32 encoded address.
     */
    Utils.hexToBech32 = function (hex, bech32Hrp) {
        return callUtilsMethod({
            name: 'hexToBech32',
            data: {
                hex: hex,
                bech32Hrp: bech32Hrp
            }
        });
    };
    /**
     * Transforms an alias id to a bech32 encoded address.
     */
    Utils.aliasIdToBech32 = function (aliasId, bech32Hrp) {
        return callUtilsMethod({
            name: 'aliasIdToBech32',
            data: {
                aliasId: aliasId,
                bech32Hrp: bech32Hrp
            }
        });
    };
    /**
     * Transforms an nft id to a bech32 encoded address.
     */
    Utils.nftIdToBech32 = function (nftId, bech32Hrp) {
        return callUtilsMethod({
            name: 'nftIdToBech32',
            data: {
                nftId: nftId,
                bech32Hrp: bech32Hrp
            }
        });
    };
    /**
     * Transforms a hex encoded public key to a bech32 encoded address.
     */
    Utils.hexPublicKeyToBech32Address = function (hex, bech32Hrp) {
        return callUtilsMethod({
            name: 'hexPublicKeyToBech32Address',
            data: {
                hex: hex,
                bech32Hrp: bech32Hrp
            }
        });
    };
    /**
     * Checks if a String is a valid bech32 encoded address.
     */
    Utils.isAddressValid = function (address) {
        return callUtilsMethod({
            name: 'isAddressValid',
            data: {
                address: address
            }
        });
    };
    /**
     * Compute the hash of a transaction essence.
     */
    Utils.hashTransactionEssence = function (essence) {
        return callUtilsMethod({
            name: 'hashTransactionEssence',
            data: {
                essence: essence
            }
        });
    };
    /**
     * Verifies an ed25519 signature against a message.
     */
    Utils.verifyEd25519Signature = function (signature, message) {
        return callUtilsMethod({
            name: 'verifyEd25519Signature',
            data: {
                signature: signature,
                message: message
            }
        });
    };
    /**
     * Verifies a Secp256k1Ecdsa signature against a message.
     */
    Utils.verifySecp256k1EcdsaSignature = function (publicKey, signature, message) {
        return callUtilsMethod({
            name: 'verifySecp256k1EcdsaSignature',
            data: {
                publicKey: publicKey,
                signature: signature,
                message: message
            }
        });
    };
    /**
     * Verify if a mnemonic is a valid BIP39 mnemonic.
     */
    Utils.verifyMnemonic = function (mnemonic) {
        return callUtilsMethod({
            name: 'verifyMnemonic',
            data: { mnemonic: mnemonic }
        });
    };
    return Utils;
}());
export { Utils };
//# sourceMappingURL=utils.js.map