import { Ed25519Signature } from '../../signature';
/**
 * All of the unlock types.
 */
declare enum UnlockType {
    Signature = 0,
    Reference = 1,
    Alias = 2,
    Nft = 3
}
declare abstract class Unlock {
    private type;
    constructor(type: UnlockType);
    /**
     * The type of unlock.
     */
    getType(): UnlockType;
}
/**
 * An unlock holding one or more signatures unlocking one or more inputs..
 */
declare class SignatureUnlock extends Unlock {
    /**
     * The signature.
     */
    signature: Ed25519Signature;
    constructor(signature: Ed25519Signature);
}
/**
 * An unlock which must reference a previous unlock which unlocks
 * also the input at the same index as this Reference Unlock.
 */
declare class ReferenceUnlock extends Unlock {
    /**
     * The reference.
     */
    reference: number;
    constructor(reference: number);
}
/**
 * An unlock which must reference a previous unlock which unlocks the alias that the input is locked to.
 */
declare class AliasUnlock extends Unlock {
    /**
     * The reference.
     */
    reference: number;
    constructor(reference: number);
}
/**
 * An unlock which must reference a previous unlock which unlocks the NFT that the input is locked to.
 */
declare class NftUnlock extends Unlock {
    /**
     * The reference.
     */
    reference: number;
    constructor(reference: number);
}
declare const UnlockDiscriminator: {
    property: string;
    subTypes: ({
        value: typeof SignatureUnlock;
        name: any;
    } | {
        value: typeof ReferenceUnlock;
        name: any;
    })[];
};
export { UnlockType, Unlock, SignatureUnlock, ReferenceUnlock, AliasUnlock, NftUnlock, UnlockDiscriminator, };
